@@ -1,4 +1,6 @@
 library(GGIR)
+context("create_test_acc_csv")
+options(encoding = "UTF-8")
 test_that("create_test_acc_csv produces a file", {
   create_test_acc_csv()
   fn = "123A_testaccfile.csv"
