@@ -1,4 +1,6 @@
 library(GGIR)
+context("ggetbout")
+options(encoding = "UTF-8")
 test_that("g.getbout produces expected output", {
   # Metric 1
   set.seed(300)
